@@ -15,6 +15,17 @@ from ailca.data.base import Data
 from ailca.data.base import Dataset
 
 
+def get_image_data(path_img_file: str) -> torch.Tensor:
+    """
+    Read an image data from a given image file in ``path_img_file``.
+
+    :param path_img_file: (*str*) Path of the image file.
+    :return: (*torch.Tensor*) A tensor object of the image file.
+    """
+
+    return torch.tensor(numpy.array(Image.open(path_img_file).convert('RGB')), dtype=torch.float)
+
+
 def load_dataset(path_metadata_file: str,
                  path_imgs: str,
                  idx_img_id: int,
@@ -39,16 +50,16 @@ def load_dataset(path_metadata_file: str,
     metadata = numpy.array(metadata_file)
     names_feats = [metadata_file.columns.values[idx_img_id]]
     name_target = None if idx_target is None else metadata_file.columns.values[idx_target]
-
     iter_range = range(0, metadata.shape[0])
     list_data = list()
 
+    # If ``verbose`` is ``True``, the loading bar is presented through the standard I/O.
     if verbose:
         iter_range = tqdm(iter_range)
 
+    # Read images in the dataset.
     for i in iter_range:
-        path_img_file = path_imgs + '/' + metadata[i, idx_img_id] + ext_img
-        img = torch.tensor(numpy.array(Image.open(path_img_file).convert('RGB')), dtype=torch.float)
+        img = get_image_data(path_imgs + '/' + metadata[i, idx_img_id] + ext_img)
 
         # Swap axes the loaded image to fit the data format into the torchvision library.
         img = torch.swapaxes(img, 0, 2)
